@@ -7,7 +7,7 @@ os.environ['TF_CPP_MIN_LOG_LEVEL'] = '3'
 
 
 class GenderPredictor:
-    def __init__(self, name: str, model_path: str = 'gender_model-Bilstm128-25-10-retrained.h5'):
+    def __init__(self, name: str, model_path: str = 'GenderPrediction/gender_model-Bilstm128-25-10-retrained.h5'):
         self.name = name
         self.model_path = model_path
         self.model = load_model(model_path)
@@ -64,8 +64,8 @@ class GenderPredictor:
         return "".join([self.ids2char[i] for i in decoded])
 
     def predict(self) -> str:
-        name = self.preprocess(self.name)
-        encoding = np.asarray([self.name_encoding(name)])
+        name_ = self.preprocess(self.name)
+        encoding = np.asarray([self.name_encoding(name_)])
         probs = self.model.predict(encoding)
         if probs >= 0.5:
             return "MALE"
